/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: image.h,v 1.4 2002/05/08 21:24:47 jdejong Exp $ */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: image.h,v 1.4 2002/05/08 21:24:47 jdejong Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jdejong 2002-05-08  imported
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */

#ifndef _IMAGE_H
#define _IMAGE_H
/*----------------------------------------------------------------------- */
/* Routines for writing standard FITS images                              */
/* I/O is a plane at a time, images are as floats                         */
/*----------------------------------------------------------------------- */
#include "fitsio.h"
#include "VLTItable.h"

typedef struct      /* structure used to store image information */
{
  char *filename;   /* image file name */
  fitsfile* fptr;   /* cfitsio pointer */
  int dtype;        /* datatype code */
  long nplane;      /* number of planes read/written so far */
  long dim[3];      /* size in pixels of image */
} image_info;

image_info* 
open_image(char *file, int *ierr);
/*----------------------------------------------------------------------- */
/*  Open an existing FITS image file                                      */
/*   Inputs:                                                              */
/*      file       name of the file to be read                            */
/*   Returns:                                                             */
/*      An image_info pointer needed for I/O; NULL indicates failure      */
/*----------------------------------------------------------------------- */

image_info* 
make_image(char *file, int bp, int  naxis[3], char *ctype[3], 
	   double crval[3], float crpix[3], float crinc[3],  
	   float crota[3], char *date_obs, int *ierr);
/*----------------------------------------------------------------------- */
/*   Create/init a FITS image file                                        */
/*   Inputs:                                                              */
/*      file       name of the file to be created                         */
/*      bp         desired bits per pixel in the image                    */
/*      naxis      dimension of two axes of data, weight arrays           */
/*      ctype      labels for the axes, NULL->ignore                      */
/*      crval      reference value for each axis , NULL->ignore           */
/*      crpix      reference pixels, NULL->ignore                         */
/*      crinc      coordinate increments, NULL->ignore                    */
/*      crota      coordinate rotations, NULL->ignore                     */
/*      date_obs   Date (yyyy-mm-dd) observations began, NULL->ignore     */
/*   Returns:                                                             */
/*      An image_info pointer needed for I/O; NULL indicates failure      */
/*----------------------------------------------------------------------- */

void kill_image_info (image_info *info);
/*----------------------------------------------------------------------- */
/*   Delete an image_info structure, should already have been closed.     */
/*   Inputs:                                                              */
/*      row    pointer to the image_info structure.                       */
/*----------------------------------------------------------------------- */

int image_read (image_info *info, float *plane, int *ierr);
/*----------------------------------------------------------------------- */
/*   Read the next plane in an image                                      */
/*   Inputs:                                                              */
/*      info      image_info for I/O                                      */
/*      plane     pointer plane data, will be converted as necessary      */
/*   Input/output:                                                        */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int image_read_raw (image_info *info, void *plane, int *ierr);
/*----------------------------------------------------------------------- */
/*   Read the next plane in an image with no type conversion              */
/*   No checks are make for invalid data.                                 */
/*   Inputs:                                                              */
/*      info      image_info for I/O                                      */
/*      plane     pointer plane data, in file format                      */
/*   Input/output:                                                        */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int image_write (image_info *info, float *plane, int *ierr);
/*----------------------------------------------------------------------- */
/*   Write  the next plane into an image                                  */
/*   Inputs:                                                              */
/*      info      image_info for I/O                                      */
/*      plane     pointer plane data, will be converted as necessary      */
/*   Input/output:                                                        */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int image_close (image_info *info, int *ierr);
/*----------------------------------------------------------------------- */
/*   Close an image updating the header                                   */
/*   Inputs:                                                              */
/*      info      image_info for I/O                                      */
/*   Input/output:                                                        */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

#endif /* end IMAGE_H */
/* */
